aboutsummaryrefslogtreecommitdiff
path: root/sword1/collision.h
diff options
context:
space:
mode:
authorTorbjörn Andersson2004-01-11 15:47:41 +0000
committerTorbjörn Andersson2004-01-11 15:47:41 +0000
commitcf0a73f913174599c7c28d910ecd87229fd62afd (patch)
tree7eabb5c16878d42f35d811ed13af5ed20b763f92 /sword1/collision.h
parent563d95c576c817a63ec64302e67b2ee5daa97c6e (diff)
downloadscummvm-rg350-cf0a73f913174599c7c28d910ecd87229fd62afd.tar.gz
scummvm-rg350-cf0a73f913174599c7c28d910ecd87229fd62afd.tar.bz2
scummvm-rg350-cf0a73f913174599c7c28d910ecd87229fd62afd.zip
Introduced new namespace, Sword1, removing the "Sword" and "Bs" prefixes in
the process, except for SwordEngine. Some minor cleanups along the wa, e.g. stdafx.h already includes <stdio.h>, <stdlib.h> and <math.h> so there shouldn't be any need to do it elsewhere. svn-id: r12320
Diffstat (limited to 'sword1/collision.h')
-rw-r--r--sword1/collision.h19
1 files changed, 12 insertions, 7 deletions
diff --git a/sword1/collision.h b/sword1/collision.h
index 168c0a49cd..3885216236 100644
--- a/sword1/collision.h
+++ b/sword1/collision.h
@@ -24,12 +24,14 @@
/*#include "objectman.h"
-class SwordLogic;
+namespace Sword1 {
-class SwordCollision {
+class Logic;
+
+class Collision {
public:
- SwordCollision(ObjectMan *pObjMan, SwordLogic *pLogic);
- ~SwordCollision(void);
+ Collision(ObjectMan *pObjMan, Logic *pLogic);
+ ~Collision(void);
void checkCollisions(void);
void fnBumpOff(void);
void fnBumpOn(void);
@@ -37,8 +39,11 @@ private:
int32 getIntersect(int32 x0, int32 y0, int32 x1, int32 y1, int32 x2, int32 y2, int32 x3, int32 y3);
int noCol;
ObjectMan *_objMan;
- SwordLogic *_logic; // for CFN_preset_script
-};*/
-// maybe it's better to make this part of SwordRouter
+ Logic *_logic; // for CFN_preset_script
+};
+
+} // End of namespace Sword1
+*/
+// maybe it's better to make this part of Router
#endif // BSCOLLISION_H